==> docker-model-1.2.0-sources.jar: annotations/io/fabric8/docker/api/model/ContainerCreateResponseBuilder.java <==
package io.fabric8.docker.api.model;

import javax.validation.Validation;
import io.fabric8.docker.api.builder.VisitableBuilder;
import java.util.Set;
import javax.annotation.Generated;
import javax.validation.ValidationException;
import javax.validation.ValidatorFactory;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;
import javax.validation.Validator;

public class ContainerCreateResponseBuilder extends ContainerCreateResponseFluentImpl<ContainerCreateResponseBuilder> implements VisitableBuilder<ContainerCreateResponse,ContainerCreateResponseBuilder>{

    ContainerCreateResponseFluent<?> fluent;
    Boolean validationEnabled;

    public ContainerCreateResponseBuilder(){
            this(true);
    }
    public ContainerCreateResponseBuilder(Boolean validationEnabled){
            this(new ContainerCreateResponse(), validationEnabled);
    }
    public ContainerCreateResponseBuilder(ContainerCreateResponseFluent<?> fluent){
            this(fluent, true);
    }
    public ContainerCreateResponseBuilder(ContainerCreateResponseFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new ContainerCreateResponse(), validationEnabled);
    }
    public ContainerCreateResponseBuilder(ContainerCreateResponseFluent<?> fluent,ContainerCreateResponse instance){
            this(fluent, instance, true);
    }
    public ContainerCreateResponseBuilder(ContainerCreateResponseFluent<?> fluent,ContainerCreateResponse instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withId(instance.getId()); 
            fluent.withWarnings(instance.getWarnings()); 
            this.validationEnabled = validationEnabled; 
    }
    public ContainerCreateResponseBuilder(ContainerCreateResponse instance){
            this(instance,true);
    }
    public ContainerCreateResponseBuilder(ContainerCreateResponse instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withId(instance.getId()); 
            this.withWarnings(instance.getWarnings()); 
            this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.docker.api.model.EditableContainerCreateResponse build(){
            EditableContainerCreateResponse buildable = new EditableContainerCreateResponse(fluent.getId(),fluent.getWarnings());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ContainerCreateResponseBuilder that = (ContainerCreateResponseBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> docker-model-1.3.0-sources.jar: annotations/io/fabric8/docker/api/model/ContainerCreateResponseBuilder.java <==
package io.fabric8.docker.api.model;

import io.fabric8.docker.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ContainerCreateResponseBuilder extends ContainerCreateResponseFluentImpl<ContainerCreateResponseBuilder> implements VisitableBuilder<ContainerCreateResponse,ContainerCreateResponseBuilder>{

    ContainerCreateResponseFluent<?> fluent;
    Boolean validationEnabled;

    public ContainerCreateResponseBuilder(){
            this(true);
    }
    public ContainerCreateResponseBuilder(Boolean validationEnabled){
            this(new ContainerCreateResponse(), validationEnabled);
    }
    public ContainerCreateResponseBuilder(ContainerCreateResponseFluent<?> fluent){
            this(fluent, true);
    }
    public ContainerCreateResponseBuilder(ContainerCreateResponseFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new ContainerCreateResponse(), validationEnabled);
    }
    public ContainerCreateResponseBuilder(ContainerCreateResponseFluent<?> fluent,ContainerCreateResponse instance){
            this(fluent, instance, true);
    }
    public ContainerCreateResponseBuilder(ContainerCreateResponseFluent<?> fluent,ContainerCreateResponse instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withId(instance.getId()); 
            fluent.withWarnings(instance.getWarnings()); 
            this.validationEnabled = validationEnabled; 
    }
    public ContainerCreateResponseBuilder(ContainerCreateResponse instance){
            this(instance,true);
    }
    public ContainerCreateResponseBuilder(ContainerCreateResponse instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withId(instance.getId()); 
            this.withWarnings(instance.getWarnings()); 
            this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.docker.api.model.EditableContainerCreateResponse build(){
            EditableContainerCreateResponse buildable = new EditableContainerCreateResponse(fluent.getId(),fluent.getWarnings());
            io.fabric8.docker.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ContainerCreateResponseBuilder that = (ContainerCreateResponseBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
